@@ -13,7 +13,6 @@
  */
 
 
-#include "pset.h"
 #include "util.h"	/* for nv_get_name() */
 #include "defs.h"	/* bool_int */
 #include "connection.h"
@@ -44,14 +43,12 @@ typedef enum
    } access_e ;
 
 
-#define access_explain( code )   nv_get_name( access_code_names, (int) (code) )
+#define ACCESS_EXPLAIN( code )   nv_get_name( access_code_names, (int) (code) )
 
 
-extern pset_h global_no_access;
-extern pset_h global_no_access_time;
-extern struct name_value access_code_names[];
-void scrub_global_access_lists(void);
-access_e access_control(struct service *sp,const connection_s *cp,const mask_t *check_mask);
+extern const struct name_value access_code_names[];
+access_e access_control(struct service *sp,
+	const connection_s *cp,const mask_t *check_mask);
 access_e parent_access_control(struct service *sp,const connection_s *cp);
 
 
