@@ -93,7 +93,8 @@ status_e log_start( struct service *sp, xlog_h *xhp )
 
       case L_SYSLOG:
          xh = xlog_create( XLOG_SYSLOG, sid, XLOG_NOFLAGS, 
-                  log_syslog( lp )->sl_facility, log_syslog( lp )->sl_level ) ;
+                  LOG_GET_SYSLOG( lp )->sl_facility,
+                  LOG_GET_SYSLOG( lp )->sl_level ) ;
          if ( xh == NULL )
          {
             msg( LOG_ERR, func, "failed to create a log for service %s", sid ) ;
@@ -108,7 +109,7 @@ status_e log_start( struct service *sp, xlog_h *xhp )
           *         it will be opened as many times.
           *         Furthermore, size control will not be accurate.
           */
-         xh = start_filelog( sid, log_filelog( lp ) ) ;
+         xh = start_filelog( sid, LOG_GET_FILELOG( lp ) ) ;
          if ( xh == NULL )
             return( FAILED ) ;
          (void) xlog_control( xh, XLOG_CALLBACK, log_in_error, (void *)sp ) ;
@@ -121,7 +122,7 @@ status_e log_start( struct service *sp, xlog_h *xhp )
             else
             {
                xh = start_filelog( "default", 
-                              log_filelog( SC_LOG( DEFAULTS( ps ) ) ) ) ;
+                              LOG_GET_FILELOG( SC_LOG( DEFAULTS( ps ) ) ) ) ;
                if ( xh == NULL )
                {
                   DEFAULT_LOG_ERROR( ps ) = TRUE ;
@@ -137,7 +138,7 @@ status_e log_start( struct service *sp, xlog_h *xhp )
 
       default:         /* SHOULDN'T HAPPEN */
          msg( LOG_ERR, func, "bad log type (%d) for service %s",
-            (int) log_get_type( lp ), sid ) ;
+            (int) LOG_GET_TYPE( lp ), sid ) ;
          return( FAILED ) ;
    }
    *xhp = xh ;
@@ -155,7 +156,7 @@ void log_end( struct log *lp, xlog_h xh )
       return ;
    }
 
-   switch ( log_get_type( lp ) )
+   switch ( LOG_GET_TYPE( lp ) )
    {
       case L_FILE:
          ps.rws.descriptors_free++ ;
