@@ -21,7 +21,7 @@
  * Macros about masks - Note: 64 bits is needed because of attr.h
  */
 
-#define mask_t uint64_t
+typedef uint64_t mask_t;
 
 #define MASK_NULL                   ((mask_t *)0)
 
