@@ -27,6 +27,8 @@ const struct name_value service_types[] =
       { "INTERNAL",                   ST_INTERNAL             },
       { "UNLISTED",                   ST_UNLISTED             },
       { "SPECIAL",                    ST_SPECIAL              },
+      { "TCPMUX",                     ST_TCPMUX               },
+      { "TCPMUXPLUS",                 ST_TCPMUXPLUS           },
       { CHAR_NULL,                    0                       }
    } ;
 
@@ -67,7 +69,7 @@ const struct name_value success_log_options[] =
       { "EXIT",        LO_EXIT     },
       { "PID",         LO_PID      },
       { "USERID",      LO_USERID   },
-      { CHAR_NULL,     0           }
+
    } ;
 
 
