@@ -9,17 +9,13 @@
 #define OPTIONS_H
 
 
-#define filelog_option_arg             filelog_option_arg_1
-#define syslog_option_arg              syslog_option_arg_1
-#define logprocs_option_arg            logprocs_option_arg_1
-
 
 extern int filelog_option;
-extern char *filelog_option_arg_1;
+extern char *filelog_option_arg;
 extern int syslog_option;
-extern char *syslog_option_arg_1;
+extern char *syslog_option_arg;
 extern int logprocs_option;
-extern unsigned logprocs_option_arg_1;
+extern unsigned logprocs_option_arg;
 extern int stayalive_option;
 extern char *program_name;
 
