@@ -43,10 +43,10 @@ static void si_mux(void) ;
 
 
 static struct intercept_ops istream_ops =
-   {
+{
       si_mux,
       si_exit
-   } ;
+} ;
 
 
 
@@ -223,7 +223,7 @@ static void connection_request( struct intercept_s *ip, channel_s **chpp )
       struct service *sp    = SERVER_SERVICE( serp ) ;
       connection_s   *cop   = SERVER_CONNECTION( serp ) ;
 
-      conn_setaddr( cop, &csin ) ;
+      CONN_SETADDR( cop, &csin ) ;
 
       if ( INTERCEPT( ip ) )
       {
