@@ -50,12 +50,12 @@ void out_of_memory( const char *func )
 
 const struct name_value *nv_find_value( const struct name_value nv_array[], const char *name )
 {
-   int i;
+   const struct name_value *nvp ;
 
-   for ( i = 0 ; nv_array[i].name ; i++ )
+   for ( nvp = nv_array ; nvp->name ; nvp++ )
    {
-      if ( EQ( name, nv_array[i].name ) )
-         return( &nv_array[i] ) ;
+      if ( EQ( name, nvp->name ) )
+         return( nvp ) ;
    }
    return( NULL ) ;
 }
